--
-- HrefUtils.hs
--
-- Copyright (c) 2003 Minero Aoki <aamine@loveruby.net>
--
-- This program is free software.
-- You can distribute/modify this program under the terms of
-- the GNU LGPL, Lesser General Public License version 2.
-- For details of the GNU LPGL, see the file "COPYING".
--

module HrefUtils
    (hrefKeyListFile, hrefDataDirEnv,
     encodePath, decodePath, moduleName, functionName,
     myGetEnv, headChar, split)
where

import System
import System.IO
import Network.URI (escapeString, unEscapeString)
import Data.Char

hrefKeyListFile = "comptable"
hrefDataDirEnv = "HREF_DATADIR"

encodePath :: String -> String
encodePath cs = escapeString cs (\c -> isAlphaNum c || c == '_')

decodePath :: String -> String
decodePath cs = unEscapeString cs

functionName :: String -> String
functionName fullName = tail.snd $ break (==',') fullName

moduleName :: String -> String
moduleName fullName = fst $ break (==',') fullName

myGetEnv :: String -> IO String
myGetEnv key =
    catch (getEnv key)
          (\e -> do hPutStrLn stderr $ "environment variable not set: " ++ key
                    exitWith $ ExitFailure 1)

headChar :: String -> Char
headChar []     = ' '
headChar (x:xs) = x

split :: Eq a => a -> [a] -> [[a]]
split sep [] = []
split sep xs = x : split sep y'
               where (x,y) = break (==sep) xs
                     y' = case y of
                            [] -> []
                            _ -> tail y
